@@ -25,15 +25,18 @@ class APIList(ListAPIView, APIPrivateView):
     def get_queryset(self):
         params = self.request.query_params
         exclude_like = params.get("exclude")
+        username = params.get("username")
+
+        if username:
+            deposits = Deposit.objects.select_related("client").filter(
+                client__username=username
+            )
+        else:
+            deposits = Deposit.objects.all()
+
         if exclude_like:
             # sql injection: A priori, nothing to worry about, django does it for
             # queryset
             # https://docs.djangoproject.com/en/3.0/topics/security/#sql-injection-protection  # noqa
-            deposits = (
-                Deposit.objects.all()
-                .exclude(external_id__startswith=exclude_like)
-                .order_by("id")
-            )
-        else:
-            deposits = Deposit.objects.all().order_by("id")
-        return deposits
+            deposits = deposits.exclude(external_id__startswith=exclude_like)
+        return deposits.order_by("id")
