@@ -10,6 +10,7 @@ from io import BytesIO
 from django.core.files.uploadedfile import InMemoryUploadedFile
 from django.urls import reverse_lazy as reverse
 from rest_framework import status
+import xmltodict
 
 from swh.deposit.config import COL_IRI, DEPOSIT_STATUS_DEPOSITED, EM_IRI, SE_IRI
 from swh.deposit.models import Deposit, DepositRequest
@@ -325,7 +326,10 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
 
     # adding file is no longer possible since the deposit's status
     # is ready
@@ -338,7 +342,10 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
 
     # replacing metadata is no longer possible since the deposit's
     # status is ready
@@ -351,7 +358,10 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
 
     # adding new metadata is no longer possible since the
     # deposit's status is ready
@@ -364,7 +374,10 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
 
     archive_content = b"some content representing archive"
     archive = InMemoryUploadedFile(
@@ -394,7 +407,10 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
 
     # adding new metadata is no longer possible since the
     # deposit's status is ready
@@ -405,4 +421,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
-    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
+    assert (
+        xmltodict.parse(r.content)["sword:error"]["summary"]
+        == "You can only act on deposit with status 'partial'"
+    )
